//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Diagnostics;

namespace EventLogging
{
	/// <summary>
	/// Summary description for EventLoggingMain.
	/// </summary>
	class EventLoggingMain
	{
		const string log = "MyEventLog";
		const string source = "EventLoggingSource";
		
		static void Main(string[] args)
		{
			EventLog myApplicationLog = new EventLog("Application",".");
			foreach(EventLogEntry entry in myApplicationLog.Entries)
			{
				Console.WriteLine("\tEntry: " + entry.Message);
			}

			// The source seems to be created in the constructor if it
			// does not exist already, so this step seems to be 
			// superfluous.
//			if(!EventLog.SourceExists(source))
//			{
//				EventLog.CreateEventSource(source, log);
//			}
                
			//Create an EventLog instance and assign its source.
			EventLog myLog = new EventLog(log, ".", source);

			//Write an informational entry to the event log.    
			myLog.WriteEntry("Writing information to the event log.");
			myLog.WriteEntry("Writing an error to the event log.", EventLogEntryType.Error);
			myLog.WriteEntry("Writing a warning to the event log.", EventLogEntryType.Warning);
			myLog.WriteEntry("Writing a success audit to the event log.", EventLogEntryType.SuccessAudit);
			myLog.WriteEntry("Writing a failure audit to the event log.", EventLogEntryType.FailureAudit);
			myLog.WriteEntry("Writing to the event log with an ID.", EventLogEntryType.Error, 1, 2);
			Console.ReadLine();
			myLog.Close();
			EventLog.DeleteEventSource("EventLoggingSource");
			EventLog.Delete("MyEventLog");
		}
	}
}
