//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Diagnostics;

namespace Sink
{
	/// <summary>
	/// Summary description for EventSinkForm.
	/// </summary>
	public class EventSinkForm : System.Windows.Forms.Form
	{
		const string log = "MyEventLog";
		const string source = "MyEventSource";
		private System.Windows.Forms.ListBox messageListBox;
		private System.Diagnostics.EventLog eventLog;
		private System.Windows.Forms.Timer timer;
		private System.ComponentModel.IContainer components;

		public EventSinkForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.eventLog.Log = log;
			this.eventLog.Source = source;
			this.eventLog.SynchronizingObject = this;
			this.eventLog.EntryWritten += new System.Diagnostics.EntryWrittenEventHandler(this.OnEntryWritten);
			try
			{
				this.eventLog.EnableRaisingEvents = true;
			}
			catch(InvalidOperationException e)
			{
				// There is probably no source yet
				// Let's just set a timer to look 
				// for the source again.
				Debug.WriteLine(e);
				timer.Enabled = true;
			}
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			this.eventLog = new System.Diagnostics.EventLog();
			this.messageListBox = new System.Windows.Forms.ListBox();
			this.timer = new System.Windows.Forms.Timer(this.components);
			((System.ComponentModel.ISupportInitialize)(this.eventLog)).BeginInit();
			this.SuspendLayout();
			// 
			// eventLog
			// 
			this.eventLog.SynchronizingObject = this;
			// 
			// messageListBox
			// 
			this.messageListBox.HorizontalScrollbar = true;
			this.messageListBox.ItemHeight = 16;
			this.messageListBox.Location = new System.Drawing.Point(8, 8);
			this.messageListBox.Name = "messageListBox";
			this.messageListBox.Size = new System.Drawing.Size(408, 244);
			this.messageListBox.TabIndex = 0;
			// 
			// timer
			// 
			this.timer.Interval = 1000;
			this.timer.Tick += new System.EventHandler(this.OnTimerTick);
			// 
			// EventSinkForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(6, 15);
			this.ClientSize = new System.Drawing.Size(424, 260);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.messageListBox});
			this.Name = "EventSinkForm";
			this.Text = "Event Sink";
			((System.ComponentModel.ISupportInitialize)(this.eventLog)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new EventSinkForm());
		}

		private void OnEntryWritten(object sender, System.Diagnostics.EntryWrittenEventArgs e)
		{
			DateTime time = e.Entry.TimeGenerated;
			string entryType = e.Entry.EntryType.ToString();
			string message = e.Entry.Message;
			string id = Convert.ToString(e.Entry.EventID);
			string cat = Convert.ToString(e.Entry.CategoryNumber);
			messageListBox.Items.Add(time + " " + entryType + " " + message + " " + id + " " + cat);
		}

		private void OnTimerTick(object sender, System.EventArgs e)
		{
			try
			{
				this.eventLog.EnableRaisingEvents = true;
				timer.Enabled = false;
			}
			catch(InvalidOperationException exception)
			{
				timer.Enabled = true;
			}
		}
	}
}
