//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Data.SqlClient;
using System.Diagnostics;
using System.IO;

namespace ValidatingData
{
	/// <summary>
	/// Summary description for ValidatingDataForm.
	/// </summary>
	public class ValidatingDataForm : System.Windows.Forms.Form
	{
		private System.Data.SqlClient.SqlConnection sqlNorthwindConnection;
		private System.Windows.Forms.DataGrid employeesDataGrid;
		private System.Windows.Forms.Button loadButton;
		private ErrorProvider errorProvider;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public ValidatingDataForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			DataGridTableStyle style = new DataGridTableStyle();
			style.MappingName = "Employees";
			style.AlternatingBackColor = System.Drawing.Color.Aquamarine;
			DataGridTextBoxColumn notes = new DataGridTextBoxColumn();
			notes.HeaderText = "Notes";
			notes.MappingName = "Notes";
			notes.TextBox.Multiline = true;
			notes.TextBox.WordWrap = true;
			notes.TextBox.AutoSize = true;
			// style.GridColumnStyles.AddRange ( new DataGridColumnStyle[] { notes } );
			employeesDataGrid.TableStyles.Add(style);

		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Collections.Specialized.NameValueCollection configurationAppSettings = System.Configuration.ConfigurationSettings.AppSettings;
			this.sqlNorthwindConnection = new System.Data.SqlClient.SqlConnection();
			this.employeesDataGrid = new System.Windows.Forms.DataGrid();
			this.loadButton = new System.Windows.Forms.Button();
			((System.ComponentModel.ISupportInitialize)(this.employeesDataGrid)).BeginInit();
			this.SuspendLayout();
			// 
			// sqlNorthwindConnection
			// 
			this.sqlNorthwindConnection.ConnectionString = configurationAppSettings.Get("sqlConnection.ConnectionString");
			// 
			// employeesDataGrid
			// 
			this.employeesDataGrid.DataMember = "";
			this.employeesDataGrid.Location = new System.Drawing.Point(8, 8);
			this.employeesDataGrid.Name = "employeesDataGrid";
			this.employeesDataGrid.Size = new System.Drawing.Size(696, 224);
			this.employeesDataGrid.TabIndex = 0;
			// 
			// loadButton
			// 
			this.loadButton.Location = new System.Drawing.Point(8, 240);
			this.loadButton.Name = "loadButton";
			this.loadButton.TabIndex = 1;
			this.loadButton.Text = "Load";
			this.loadButton.Click += new System.EventHandler(this.OnLoadData);
			// 
			// ValidatingDataForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(720, 273);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.loadButton,
																		  this.employeesDataGrid});
			this.Name = "ValidatingDataForm";
			this.Text = "Validating Employees";
			((System.ComponentModel.ISupportInitialize)(this.employeesDataGrid)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new ValidatingDataForm());
		}

		private void OnLoadData(object sender, System.EventArgs e)
		{
			errorProvider = new ErrorProvider();
			errorProvider.ContainerControl = this;
			errorProvider.BlinkRate = 200;

			string select = "SELECT EmployeeID, LastName, FirstName, Title, BirthDate, HireDate, Notes FROM Employees";
			SqlDataAdapter cmd = new SqlDataAdapter(select, sqlNorthwindConnection);
			Employees ds = new Employees();
			cmd.Fill(ds, "Employees");
			employeesDataGrid.SetDataBinding(ds, "Employees");

			errorProvider.DataSource = ds;
			errorProvider.DataMember = "Employees";

			foreach (DataRow row in (ds.EmployeesTable.Rows)) 
			{
				row.ClearErrors();
				DateTime hd = Convert.ToDateTime(row["HireDate"]);
				TimeSpan seniority = DateTime.Now - hd;
				if (seniority.TotalDays/365.25 > 9) 
				{
					row.RowError = "Is this employee due for a raise?";
					row.SetColumnError("HireDate", string.Format("This employee is has been working for us for {0:F0} years.", seniority.TotalDays/365.25));
				} 
			} 
		}
	}
}
