//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace Validation
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class ValidationForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label rangeLabel;
		private System.Windows.Forms.TextBox range;
		private System.Windows.Forms.Label alphaLabel;
		private System.Windows.Forms.TextBox alpha;
		private ErrorProvider errorProvider;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public ValidationForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			errorProvider = new ErrorProvider();

		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.range = new System.Windows.Forms.TextBox();
			this.rangeLabel = new System.Windows.Forms.Label();
			this.alphaLabel = new System.Windows.Forms.Label();
			this.alpha = new System.Windows.Forms.TextBox();
			this.SuspendLayout();
			// 
			// range
			// 
			this.range.Location = new System.Drawing.Point(216, 16);
			this.range.Name = "range";
			this.range.TabIndex = 1;
			this.range.Text = "";
			this.range.Validating += new System.ComponentModel.CancelEventHandler(this.OnRangeValidating);
			// 
			// rangeLabel
			// 
			this.rangeLabel.Location = new System.Drawing.Point(8, 24);
			this.rangeLabel.Name = "rangeLabel";
			this.rangeLabel.Size = new System.Drawing.Size(152, 16);
			this.rangeLabel.TabIndex = 0;
			this.rangeLabel.Text = "Enter a number from 1 to 10";
			// 
			// alphaLabel
			// 
			this.alphaLabel.Location = new System.Drawing.Point(8, 56);
			this.alphaLabel.Name = "alphaLabel";
			this.alphaLabel.Size = new System.Drawing.Size(192, 16);
			this.alphaLabel.TabIndex = 2;
			this.alphaLabel.Text = "Enter any alphanumeric characters";
			// 
			// alpha
			// 
			this.alpha.Location = new System.Drawing.Point(216, 48);
			this.alpha.Name = "alpha";
			this.alpha.TabIndex = 3;
			this.alpha.Text = "";
			this.alpha.Validating += new System.ComponentModel.CancelEventHandler(this.OnAlphaNumericValidating);
			// 
			// ValidationForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(336, 101);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.alpha,
																		  this.alphaLabel,
																		  this.range,
																		  this.rangeLabel});
			this.Name = "ValidationForm";
			this.Text = "Validation of User Input";
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new ValidationForm());
		}

		private void OnRangeValidating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			TextBox t = sender as TextBox;
			try 
			{
				int x = Int32.Parse(t.Text);
				if(x > 0 && x <= 10)
					errorProvider.SetError(t, "");
				else
				{
                    errorProvider.SetError(t, string.Format("Invalid range. {0} is not between 1 and 10", x));
					throw new ArgumentOutOfRangeException(t.ToString(), x, "Enter a numbr from 1 to 10");
				}
			}
			catch(FormatException) 
			{
				errorProvider.SetError(t, string.Format("\"{0}\" is not an integer value.", t.Text));
				throw;
			}
			catch(OverflowException) 
			{
				errorProvider.SetError(t, string.Format("Resulting integer is > {0} or < {1}.", Int32.MaxValue, Int32.MinValue));
				throw;
			}
			catch(ArgumentNullException) 
			{
				errorProvider.SetError(t, "Null string.");
				throw;
			}
		}

		private void OnAlphaNumericValidating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			string characters = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
			TextBox t = sender as TextBox;
			errorProvider.SetError(t, "");
			foreach(char c in t.Text)
			{
				if(characters.IndexOf(c) == -1)
				{
					errorProvider.SetError(t, "Please enter an alphanumeric value.");
					throw new ArgumentOutOfRangeException(t.ToString(), c, "Must enter an alphanumeric value");
				}
			}
		}
	}
}
